@@ -52,6 +52,7 @@ class DynamicFormsSerializer(RenderMixin, ActionMixin):
                 field.allow_null = True
                 field.read_only = False
                 field.display_form = field.display_table  # filter's form is same as non-filter's table
+                field.allow_tags = False
 
     @property
     def has_non_field_errors(self):
@@ -199,11 +200,15 @@ class ModelSerializer(DynamicFormsSerializer, serializers.ModelSerializer):
 
     def __init__(self, *args, is_filter: bool = False, **kwds):
         if hasattr(self, 'Meta') and hasattr(self.Meta, 'fields'):
-            if self.Meta.fields != '__all__' and 'df_prev_id' not in self.Meta.fields:
-                self.Meta.fields += 'df_prev_id',
+            self._make_df_special_fields_present_in_fields(['df_prev_id', 'row_css_style'])
         super().__init__(*args, is_filter=is_filter, **kwds)
         self.manage_changed_flds()
 
+    def _make_df_special_fields_present_in_fields(self, fields):
+        for f in fields:
+            if self.Meta.fields != '__all__' and f not in self.Meta.fields:
+                self.Meta.fields += f,
+
     serializer_field_mapping = {
         models.AutoField: fields.IntegerField,
         models.BigIntegerField: fields.IntegerField,
@@ -243,11 +248,17 @@ class ModelSerializer(DynamicFormsSerializer, serializers.ModelSerializer):
         When there is a need to only change few parameters of a field put those fields and changed parameters in
         serializers Meta class in parameter changed_flds.
 
-        Exsample:
-        changed_flds = {'id': dict(display=DisplayMode.HIDDEN),
-                        'comment': dict(label='Comm', help_text='Help text for comment field')
-                        }
+        Example:
+
+        .. code-block:: python
+
+           changed_flds = {
+               'id': dict(display=DisplayMode.HIDDEN),
+               'comment': dict(label='Comm', help_text='Help text for comment field')
+           }
+
         :return:
+
         """
         if hasattr(self.Meta, 'changed_flds'):
             for field, params in self.Meta.changed_flds.items():
@@ -259,6 +270,9 @@ class ModelSerializer(DynamicFormsSerializer, serializers.ModelSerializer):
     # Dynamic forms default field that is used to contain data for positioning (id of previous record)
     df_prev_id = fields.SerializerMethodField(display=DisplayMode.HIDDEN)
 
+    # this is a calculated field that returns css style for table row
+    row_css_style = fields.SerializerMethodField(display=DisplayMode.HIDDEN)
+
     def fetch_prev_id(self, obj, view):
         ordering = 'id'
         try:
@@ -292,6 +306,10 @@ class ModelSerializer(DynamicFormsSerializer, serializers.ModelSerializer):
 
         return ''
 
+    # noinspection PyMethodMayBeStatic
+    def get_row_css_style(self, obj):
+        return ''
+
 
 class Serializer(DynamicFormsSerializer, serializers.Serializer):
 
